# User Guide
This section familiarizes you with all library concepts. It uses https://httpbin.org/ service to demonstrate how applied changed are affeted to behaviour. All examples you find could be copy-pasted and run in your environment (sometimes same parts are ommited, but you can always find a full code in attached snippets).

## How read this guide?
To dive into `reqsnaked` the first time, reading [Understand the basics](./basics.md) firstly is recommend. Then the order will not be important.

!!! Note
    Currently the `reqsnaked` support only `#!python async/await` style, for sync requests use [Requests](https://github.com/psf/requests) library.

!!! Tip
    If you know a `reqwest` feature that did not implemented by `reqsnaked`, a PR would be a pleasure.
